==> muon-1.4.1.tar.bz2: muon-1.4.1/updater/ChangelogWidget.h <==
/***************************************************************************
 *   Copyright © 2011 Jonathan Thomas <echidnaman@kubuntu.org>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef CHANGELOGWIDGET_H
#define CHANGELOGWIDGET_H

#include <QtCore/QHash>
#include <QtGui/QWidget>

class QParallelAnimationGroup;

class KJob;
class KPixmapSequenceOverlayPainter;
class KTemporaryFile;
class KTextBrowser;

namespace QApt {
    class Backend;
    class Changelog;
    class Package;
}

class ChangelogWidget : public QWidget
{
    Q_OBJECT
public:
    explicit ChangelogWidget(QWidget *parent = 0);

private:
    QApt::Backend *m_backend;
    QApt::Package *m_package;
    QHash<KJob *, QString> m_jobHash;
    QString m_jobFileName;
    bool m_show;

    QParallelAnimationGroup *m_expandWidget;
    KTextBrowser *m_changelogBrowser;
    KPixmapSequenceOverlayPainter *m_busyWidget;

    QString buildDescription(const QApt::Changelog &log);

public Q_SLOTS:
    void setBackend(QApt::Backend *backend);
    void setPackage(QApt::Package *package);
    void show();
    void animatedHide();
    void stopPendingJobs();

private Q_SLOTS:
    void fetchChangelog();
    void changelogFetched(KJob *job);
};

#endif

==> muon_2.0.0.orig.tar.bz2: muon-2.0.0/updater/ChangelogWidget.h <==
/***************************************************************************
 *   Copyright © 2011 Jonathan Thomas <echidnaman@kubuntu.org>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef CHANGELOGWIDGET_H
#define CHANGELOGWIDGET_H

#include <QtCore/QSet>
#include <QtGui/QWidget>

class QParallelAnimationGroup;

class KJob;
class KPixmapSequenceOverlayPainter;
class KTemporaryFile;
class KTextBrowser;

namespace QApt { class Package; }

class ChangelogWidget : public QWidget
{
    Q_OBJECT
public:
    explicit ChangelogWidget(QWidget *parent = 0);

private:
    QApt::Package *m_package;
    QSet<KJob *> m_jobHash;
    QString m_jobFileName;
    bool m_show;

    QParallelAnimationGroup *m_expandWidget;
    KTextBrowser *m_changelogBrowser;
    KPixmapSequenceOverlayPainter *m_busyWidget;

    QString buildDescription(const QByteArray& data, const QString& source);

public Q_SLOTS:
    void setPackage(QApt::Package *package);
    void show();
    void animatedHide();
    void stopPendingJobs();

private Q_SLOTS:
    void fetchChangelog();
    void changelogFetched(KJob *job);
};

#endif
